summaryrefslogtreecommitdiffstats
path: root/test/cache.c
diff options
context:
space:
mode:
authorAllen Byrne <50328838+byrnHDF@users.noreply.github.com>2023-02-16 13:23:09 (GMT)
committerGitHub <noreply@github.com>2023-02-16 13:23:09 (GMT)
commitaf9659d8475123d25f2235ef09b39567c4e2dde0 (patch)
treeb94ef18a88c9c0a18f1cd027cf19f7d1487440da /test/cache.c
parent5b79bb2f0f0c9722da2236deef2875291bdb7bde (diff)
downloadhdf5-af9659d8475123d25f2235ef09b39567c4e2dde0.zip
hdf5-af9659d8475123d25f2235ef09b39567c4e2dde0.tar.gz
hdf5-af9659d8475123d25f2235ef09b39567c4e2dde0.tar.bz2
1.10: Add spelling check to CI and fix errors. (#2442)
* Update CI and support files to match latest from 1.14 * Correct spelling * More spelling corrections * spelling fixes in testpar * Fix spelling errors in tools * More tools spelling fixes * Spelling fixes for rest of tools and some src * Fix spelling errors in src files, pt 2 * Fix spelling in src pt3 * Fix spelling errors pt4 * Fix spelling errors pt5 * Spelling fix pt6 * fix spelling error examples * fix spelling in tests * fix spelling errors in test pt2 * Fix spelling errors in test pt3 * fix spelling in test pt4 * Fix spelling errors in hl * fix spelling errors in c++ * Spelling fixes for fortran * spelling fixes for bin and java * Add relative path * Change spelling action to use a file for list of ignore words * Fix spelling ignore list * remove unused file
Diffstat (limited to 'test/cache.c')
-rw-r--r--test/cache.c68
1 files changed, 34 insertions, 34 deletions
diff --git a/test/cache.c b/test/cache.c
index 8ab5838..41be0d4 100644
--- a/test/cache.c
+++ b/test/cache.c
@@ -2789,8 +2789,8 @@ write_permitted_check(int
* Test the behaviour with different flags.
*
* This test was added primarily to test basic insert
- * pinned entry functionallity, but I through in explicit
- * tests for other functionallity that is tested implicitly
+ * pinned entry functionality, but I through in explicit
+ * tests for other functionality that is tested implicitly
* elsewhere.
*
* Return: void
@@ -2908,7 +2908,7 @@ check_insert_entry(unsigned paged)
}
}
- /* Thats all we can get from H5C_get_entry_status().
+ /* That's all we can get from H5C_get_entry_status().
* Now start looking at the cache data structures directly.
*/
@@ -5186,7 +5186,7 @@ check_flush_cache__flush_ops(H5F_t *file_ptr)
*
* 10/8/07 -- JRM
* Added a resize operation to this test to satisfy the new
- * requiremnt that any resize of an entry on flush will always
+ * requirement that any resize of an entry on flush will always
* be accompanied by a resize. Note that as a result, this
* test becomes redundant with later tests.
*/
@@ -5283,7 +5283,7 @@ check_flush_cache__flush_ops(H5F_t *file_ptr)
*
* 10/8/07 -- JRM
* Added a resize operation to this test to satisfy the new
- * requiremnt that any resize of an entry on flush will always
+ * requirement that any resize of an entry on flush will always
* be accompanied by a resize. Note that as a result, this
* test becomes redundant with later tests.
*/
@@ -8892,7 +8892,7 @@ check_flush_cache__flush_op_eviction_test(H5F_t *file_ptr)
*
* (VET, 9) Y 10 KB N N - dirty (VET, 8)
*
- * Recall that in this test bed, flush operations are excuted the
+ * Recall that in this test bed, flush operations are executed the
* first time the associated entry is flushed, and are then
* deleted.
*/
@@ -9445,7 +9445,7 @@ check_flush_cache__flush_op_eviction_test(H5F_t *file_ptr)
* returns to the serialize function for (VET, 9).
*
* When the serialize function for (VET, 9) is done with (VET, 8), it
- * calls H5C_unprotect(VET, 8), which markes (VET, 8) as dirty and
+ * calls H5C_unprotect(VET, 8), which marks (VET, 8) as dirty and
* unprotected, and places it at the head of the LRU.
*
* (VET, 0) is the next item on the LRU -- it is clean and is therefore
@@ -9846,7 +9846,7 @@ check_flush_cache__flush_op_eviction_test(H5F_t *file_ptr)
* Added tests for pinned entries.
*
* JRM -- 5/17/06
- * Complete reqrite of pinned entry tests to accomodate
+ * Complete rewrite of pinned entry tests to accommodate
* the new H5C_mark_entry_dirty() call.
*
*-------------------------------------------------------------------------
@@ -11842,7 +11842,7 @@ check_expunge_entry(unsigned paged)
* Function: check_multiple_read_protect()
*
* Purpose: Verify that multiple, simultaneous read protects of a
- * single entry perform as expectd.
+ * single entry perform as expected.
*
* Return: void
*
@@ -12188,7 +12188,7 @@ check_multiple_read_protect(unsigned paged)
if (pass && (entry_ptr->header.is_pinned)) {
pass = FALSE;
- failure_mssg = "enty (0,4) still pinned.\n";
+ failure_mssg = "entry (0,4) still pinned.\n";
}
unprotect_entry(file_ptr, 0, 4, /* (0,4) unprotect */
@@ -14391,7 +14391,7 @@ check_destroy_protected_err(unsigned paged)
* Function: check_duplicate_insert_err()
*
* Purpose: Verify that an attempt to insert and entry that is
- * alread in the cache will generate an error.
+ * already in the cache will generate an error.
*
* Return: void
*
@@ -16947,7 +16947,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* eigth epoch -- force the hit rate to 100% again -- should be steady
+ /* eight epoch -- force the hit rate to 100% again -- should be steady
* state.
*/
if (pass) {
@@ -17043,7 +17043,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- if (pass) { /* twelth epoch -- at minimum size so no more ageouts */
+ if (pass) { /* twelfth epoch -- at minimum size so no more ageouts */
rpt_fcn_called = FALSE;
i = 0;
while (pass && (i < 1000)) {
@@ -17324,7 +17324,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* eigth epoch -- still 100% hit rate
+ /* eighth epoch -- still 100% hit rate
*/
if (pass) {
@@ -17427,7 +17427,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
/* twelth epoch -- force the hit rate to 100% again -- should be steady
* state.
*/
if (pass) {
@@ -17803,7 +17803,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* eigth epoch -- force the hit rate to 100% again -- should be steady
+ /* eighth epoch -- force the hit rate to 100% again -- should be steady
* state.
*/
if (pass) {
@@ -17903,7 +17903,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- if (pass) { /* twelth epoch -- at minimum size so no more ageouts */
+ if (pass) { /* twelfth epoch -- at minimum size so no more ageouts */
rpt_fcn_called = FALSE;
i = 0;
@@ -18554,7 +18554,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
/* twelth epoch -- hit rate 1.0 -- decrease as before.
*/
if (pass) {
@@ -19567,7 +19567,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* protect and unprotect two more large entries -- shouldnt trigger a
+ /* protect and unprotect two more large entries -- shouldn't trigger a
* flash cache size increase.
*/
if (pass) {
@@ -22127,7 +22127,7 @@ check_auto_cache_resize_disable(unsigned paged)
* mode (add space), which is triggered whenever the size of a newly
* loaded or inserted entry, or the delta between old and new entry
* sizes exceeds some fraction of the current maximum cache size, and
- * the cache doesn't have enough free space to accomodate the new/
+ * the cache doesn't have enough free space to accommodate the new/
* resize entry without performing evictions. The range of permissible
* values for the flash_threshold (0.1 to 1.0 as of this writing), and
* for the flash_multiple (0.1 to 10.0) do not permit the facility to
@@ -22136,7 +22136,7 @@ check_auto_cache_resize_disable(unsigned paged)
* current max_cache_size equal to max_size.
*
* We have already tested the latter in check_auto_cache_resize(), so
- * we need only thest the former here. Do this by disabling flash
+ * we need only test the former here. Do this by disabling flash
* cache size increments via the flash_incr_mode, and then creating
* situations that would trigger flash cache size increases were that
* code enabled.
@@ -25209,7 +25209,7 @@ check_auto_cache_resize_input_errs(unsigned paged)
/*-------------------------------------------------------------------------
* Function: check_auto_cache_resize_aux_fcns()
*
* Purpose: Verify that the auxilary functions associated with
* the automatic cache resize capability are operating
* correctly. These functions are:
*
@@ -25286,13 +25286,13 @@ check_auto_cache_resize_aux_fcns(unsigned paged)
};
if (paged)
- TESTING("automatic cache resize auxilary functions (paged aggregation)")
+ TESTING("automatic cache resize auxiliary functions (paged aggregation)")
else
- TESTING("automatic cache resize auxilary functions")
+ TESTING("automatic cache resize auxiliary functions")
pass = TRUE;
/* allocate a cache, and then test the various auxilary functions.
*/
if (pass) {
@@ -25814,7 +25814,7 @@ check_metadata_blizzard_absence(hbool_t fill_via_insertion, unsigned paged)
if (file_ptr == NULL) {
pass = FALSE;
- failure_mssg = "bad return from cache intialization.\n";
+ failure_mssg = "bad return from cache initialization.\n";
}
else
cache_ptr = file_ptr->shared->cache;
@@ -26033,7 +26033,7 @@ check_metadata_blizzard_absence(hbool_t fill_via_insertion, unsigned paged)
H5C__DIRTIED_FLAG); /* unsigned int flags */
}
- /* Expected staus is that after each insertion, the entry
+ /* Expected status is that after each insertion, the entry
* inserted 26 insertions ago has been flushed, and the
* entry currently getting inserted is now in the cache and
* dirty.
@@ -28440,7 +28440,7 @@ check_flush_deps_err(unsigned paged)
result =
H5C_destroy_flush_dependency(&((entries[entry_type])[0]), &((entries[entry_type])[1]));
if (result != FAIL)
- CACHE_ERROR("Destroying [non-existant] dependency when parent isn't protected")
+ CACHE_ERROR("Destroying [non-existent] dependency when parent isn't protected")
break;
/* Verify that parent entry has flush dependency */
@@ -31671,7 +31671,7 @@ check_metadata_cork(hbool_t fill_via_insertion, unsigned paged)
if (file_ptr == NULL) {
pass = FALSE;
- failure_mssg = "bad return from cache intialization.\n";
+ failure_mssg = "bad return from cache initialization.\n";
}
else
cache_ptr = file_ptr->shared->cache;
@@ -32183,7 +32183,7 @@ check_metadata_cork(hbool_t fill_via_insertion, unsigned paged)
* an entry that is no longer in the cache, and which may have
* been deleted.
*
- * This function contans tests for correct handling on this
+ * This function contains tests for correct handling on this
* situation.
*
* Do nothing if pass is FALSE on entry.
@@ -32440,7 +32440,7 @@ cedds__expunge_dirty_entry_in_flush_test(H5F_t *file_ptr)
*
* (HET, 3) Y 16 KB Y N - -
*
- * Recall that in this test bed, flush operations are excuted the
+ * Recall that in this test bed, flush operations are executed the
* first time the associated entry is flushed, and are then
* deleted.
*/
@@ -32694,7 +32694,7 @@ cedds__H5C_make_space_in_cache(H5F_t *file_ptr)
*
* (HET, 3) Y 16 KB N N - -
*
- * Recall that in this test bed, flush operations are excuted the
+ * Recall that in this test bed, flush operations are executed the
* first time the associated entry is flushed, and are then
* deleted.
*/
@@ -33112,7 +33112,7 @@ cedds__H5C__autoadjust__ageout__evict_aged_out_entries(H5F_t *file_ptr)
*
* (MET, 1-31) Y 64 KB N N - -
*
- * Recall that in this test bed, flush operations are excuted the
+ * Recall that in this test bed, flush operations are executed the
* first time the associated entry is flushed, and are then
* deleted.
*/
@@ -33479,7 +33479,7 @@ cedds__H5C_flush_invalidate_cache__bucket_scan(H5F_t *file_ptr)
if (pass) {
- /* load the entry that will have a flush dependencey with (MET, 0),
+ /* load the entry that will have a flush dependency with (MET, 0),
* thus preventing it from being flushed on the first pass through
* the skip list.
*/
@@ -17427,7 +17427,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* twelth epoch -- force the hit rate to 100% again -- should be steady
+ /* twelfth epoch -- force the hit rate to 100% again -- should be steady
* state.
*/
@@ -18554,7 +18554,7 @@ check_auto_cache_resize(hbool_t cork_ageout, unsigned paged)
if (show_progress)
HDfprintf(stderr, "check point %d\n", checkpoint++);
- /* twelth epoch -- hit rate 1.0 -- decrease as before.
+ /* twelfth epoch -- hit rate 1.0 -- decrease as before.
*/
if (pass) {
@@ -25209,7 +25209,7 @@ check_auto_cache_resize_input_errs(unsigned paged)
* Function: check_auto_cache_resize_aux_fcns()
*
- * Purpose: Verify that the auxilary functions associated with
+ * Purpose: Verify that the auxiliary functions associated with
* the automatic cache resize capability are operating
* correctly. These functions are:
@@ -25286,13 +25286,13 @@ check_auto_cache_resize_aux_fcns(unsigned paged)
pass = TRUE;
- /* allocate a cache, and then test the various auxilary functions.
+ /* allocate a cache, and then test the various auxiliary functions.
*/
if (pass) {